configparser

package
v0.0.0-...-094b2e0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 12, 2019 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetDummySwitchConfig

func GetDummySwitchConfig(switchName string) (ds.SwitchConfig, error)

GetDummySwitchConfig tries to parse the config file via viper and returns on success a dummySwitch.SwitchConfig object.

func GetMPGPIOSwitchConfig

func GetMPGPIOSwitchConfig(switchName string) (mpGPIO.SwitchConfig, error)

GetMPGPIOSwitchConfig tries to parse the config file via viper and returns on success a mpGPIO.SwitchConfig object.

func GetSmGPIOConfig

func GetSmGPIOConfig(smName string) (smGPIO.SmConfig, error)

GetSmGPIOConfig tries to parse the config file via viper and returns on success a StackmatchGPIO.SmConfig object.

Types

This section is empty.

Jump to